@@ -19,12 +19,15 @@
 import collections
 import logging
 
+from dateutil import parser
+
 from sushy import exceptions
 from sushy.resources import base
 from sushy.resources.chassis import chassis
 from sushy.resources import common
 from sushy.resources import constants as res_cons
 from sushy.resources.manager import manager
+from sushy.resources.manager import virtual_media
 from sushy.resources import settings
 from sushy.resources.system import bios
 from sushy.resources.system import constants as sys_cons
@@ -59,6 +62,23 @@ class BootField(base.CompositeField):
     http_boot_uri = base.Field('HttpBootUri')
 
 
+class BootProgressField(base.CompositeField):
+
+    last_boot_seconds_count = base.Field('LastBootTimeSeconds',
+                                         adapter=utils.int_or_none)
+    """The number of seconds the last boot took to reach OSRunning."""
+
+    last_state = base.MappedField('LastState', sys_cons.BootProgressStates)
+    """The last recorded boot progress states."""
+
+    last_state_updated_at = base.Field('LastStateTime',
+                                       adapter=parser.parse)
+    """The date-time value when the last state field was updated."""
+
+    oem_last_state = base.Field('OemLastState')
+    """The OEM last state time to describe OEM specific state information."""
+
+
 class MemorySummaryField(base.CompositeField):
     health = base.Field(['Status', 'HealthRollup'])
     """The overall health state of memory.
@@ -140,6 +160,9 @@ class System(base.ResourceBase):
 
     _actions = ActionsField('Actions', required=True)
 
+    boot_progress = BootProgressField('BootProgress')
+    """The last updated boot progress indicator"""
+
     def __init__(self, connector, identity, redfish_version=None,
                  registries=None, root=None):
         """A class representing a ComputerSystem
@@ -316,7 +339,7 @@ class System(base.ResourceBase):
                 # to the intent of "use whatever the dhcp server says".
                 data['Boot']['HttpBootUri'] = None
             else:
-                # Explicilty set the URI.
+                # Explicitly set the URI.
                 data['Boot']['HttpBootUri'] = http_boot_uri
         elif not http_boot_uri:
             # We're not doing boot from URL, we should cleanup any setting
@@ -526,6 +549,18 @@ class System(base.ResourceBase):
             redfish_version=self.redfish_version,
             registries=self.registries, root=self.root)
 
+    @property
+    @utils.cache_it
+    def virtual_media(self):
+        """Property to reference `VirtualMedia` instance
+
+        :returns: A `VirtualMediaCollection` instance.
+        """
+        return virtual_media.VirtualMediaCollection(
+            self._conn, utils.get_sub_resource_path_by(self, 'VirtualMedia'),
+            redfish_version=self.redfish_version, registries=self.registries,
+            root=self.root)
+
 
 class SystemCollection(base.ResourceCollectionBase):
 
